%global pypi_name joblib

%global common_description						\
Joblib is a set of tools to provide lightweight pipelining in Python.	\
In particular, joblib offers:						\
 * transparent disk-caching of the output values and lazy		\
   re-evaluation (memorize pattern)					\
 * easy simple parallel computing					\
 * logging and tracing of the execution

# Sources from PYPI doesn't have all needed files for doc build
%bcond_with doc

%global commit 5991350e03493fbf27bb596429a935e0c40fb536

Name:          python-%{pypi_name}
Version:       1.2.0
Release:       %mkrel 1
Summary:       Lightweight pipelining: using Python functions as pipeline jobs
License:       BSD
Group:         Development/Python

URL:           https://github.com/joblib/joblib
#Source0:       https://files.pythonhosted.org/packages/source/j/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
Source0:        https://github.com/joblib/joblib/archive/%{commit}.tar.gz
BuildArch:     noarch


%description
%{common_description}.


%package -n python3-%{pypi_name}
Summary: Lightweight pipelining: using Python3 functions as pipeline jobs
BuildArch:     noarch
BuildRequires: pkgconfig(python3)
BuildRequires: python3dist(numpy)
BuildRequires: python3dist(setuptools)

# for docs
%if %{with doc}
BuildRequires: python3dist(sphinx)
BuildRequires: python3dist(sphinx-gallery)
BuildRequires: python3dist(sphinx-rtd-theme)
BuildRequires: python3dist(numpydoc)
%endif

Requires:      python3-numpy

%description -n python3-%{pypi_name}
%{common_description}.


%prep
%autosetup -n joblib-%{commit} -p1

# drop bundled egg-info
rm -rf %{pypi_name}.egg-info/

%build
%py3_build

%if %{with doc}
PYTHONPATH=$(pwd) sphinx-build -b html doc doc/_build/html/
rm -rf doc/_build/html/.buildinfo
%endif

%install
%py3_install

%files -n python3-%{pypi_name}
%license LICENSE.txt
%doc README.rst
%if %{with doc}
%doc doc/_build/html/
%endif
%{python3_sitelib}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info


%changelog
* Wed Oct 12 2022 papoteur <papoteur> 1.2.0-1.mga8
+ Revision: 1896407
- new 1.2.0, fix CVE-2022-21797 (mga#30956)

* Fri Dec 18 2020 joequant <joequant> 1.0.0-1.mga8
+ Revision: 1660570
- update to 1.0.0

* Sun Feb 16 2020 umeabot <umeabot> 0.13.2-4.mga8
+ Revision: 1533722
- Mageia 8 Mass Rebuild

* Tue Sep 24 2019 tv <tv> 0.13.2-3.mga8
+ Revision: 1445350
- Backport all patches from upstream to fix python3.8 compat
- rebuild for python-3.8
- drop python2 subpkg

* Tue Aug 20 2019 wally <wally> 0.13.2-2.mga8
+ Revision: 1430436
- disable doc build
- drop unused pytest BRs

* Sun Apr 21 2019 wally <wally> 0.13.2-1.mga7
+ Revision: 1394230
- new version 0.13.2

* Tue Jan 08 2019 tv <tv> 0.12.2-3.mga7
+ Revision: 1351673
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.12.2-2.mga7
+ Revision: 1289153
- Mageia 7 Mass Rebuild

* Thu Aug 16 2018 eatdirt <eatdirt> 0.12.2-1.mga7
+ Revision: 1251942
- Upgrade to version 0.12.2

* Sat Aug 05 2017 pterjan <pterjan> 0.9.0b4-3.mga7
+ Revision: 1135465
- Rebuild for python 3.6

* Sat Feb 20 2016 umeabot <umeabot> 0.9.0b4-2.mga6
+ Revision: 971187
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 shlomif <shlomif> 0.9.0b4-1.mga6
+ Revision: 889661
- New version 0.9.0 + Rebuild for Python3 3.5.x
+ tv <tv>
- rebuild for python 3.5

* Mon Dec 22 2014 joequant <joequant> 0.8.3-1.mga5
+ Revision: 804763
- fix group
- imported package python-joblib

